@@ -10,9 +10,6 @@ from pathlib import Path
 from traceback import format_exception
 from warnings import warn
 import signal
-import os
-import subprocess
-import platform
 
 import docstring_parser as dp
 import pandas as pd
@@ -644,13 +641,4 @@ def hierarchicalUpdate(curDict: dict, other: dict, replaceLists=False):
       curVal.extend(v)
     else:
       curDict[k] = v
-  return curDict
-
-def openInEditor(filepath: FilePath):
-  filepath = str(filepath)
-  if platform.system() == 'Darwin':       # macOS
-      subprocess.call(('open', filepath))
-  elif platform.system() == 'Windows':    # Windows
-      os.startfile(filepath)
-  else:                                   # linux variants
-      subprocess.call(('xdg-open', filepath))
\ No newline at end of file
+  return curDict
\ No newline at end of file
