@@ -208,8 +208,9 @@ class ParamEditor(QtWidgets.QDockWidget):
 
     if self.stateName == newName:
       return
-
+    self.watcher.removePath(str(self.formatFileName()))
     self.stateName = newName
+    self.watcher.addPath(str(self.formatFileName()))
     self.stateSelector.setValue(self.stateName)
     return newState
 
