@@ -30,7 +30,7 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
   """
   Docks that should be shown in a main window's menu bar. By default, just the toolsEditor is shown.
   If multiple param editors must be visible, manually set this property to a
-  :class:`PrjParamEditorDockGrouping` as performed in :class:`XYVerticesPlugin`.
+  :class:`ParamEditorDockGrouping` as performed in :class:`TableFieldPlugin`.
   """
   toolsEditor: pe.ParamEditor
   """Param Editor window which holds user-editable properties exposed by the programmer"""
@@ -66,7 +66,10 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     cls.toolsEditor = pe.ParamEditor.buildClsToolsEditor(cls, cls._toolsEditorName)
     if cls._showFuncDetails:
       cls.dock.addEditors([cls.toolsEditor])
-    cls.menu = QtWidgets.QMenu(cls.name)
+    menuName = cls.name
+    if '&' not in menuName:
+      menuName = '&' + menuName
+    cls.menu = QtWidgets.QMenu(menuName)
 
   def __init__(self, *args, **kwargs):
     if self.dock is not None:
@@ -120,8 +123,6 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     return proc
 
   def registerPopoutFuncs(self, funcList: Sequence[Callable], nameList: Sequence[str]=None, groupName:str=None, btnOpts: PrjParam=None):
-    # TODO: I really don't like this. Consider any refactoring option that doesn't
-    #   have an import inside a function
     if groupName is None and btnOpts is None:
       raise ValueError('Must provide either group name or button options')
     elif btnOpts is None:
