@@ -90,10 +90,10 @@ def addNestedToParam(stage: NestedProcess, parentParam: Parameter, nestHyperpara
     addAtomicToParam(collapsed, parentParam, argNameFormat)
     return
   # Special case of a process comprised of just one atomic function
-  if len(stage.stages) == 1:
-    # Hide this level of the process tree
-    addStageToParam(stage.stages[0], parentParam, nestHyperparams=False)
-    return
+  # if len(stage.stages) == 1:
+  #   # Hide this level of the process tree
+  #   addStageToParam(stage.stages[0], parentParam, nestHyperparams=False)
+  #   return
   for childStage in stage:
     addStageToParam(childStage, parentParam)
 
